//////////////////////////////////////////////////////////////////////////////////
//
// JSQL2XLS
// simple pure java program to compare performances (Java Vs. RPG)
// usage: java JSQL2XLS "select . . . from . . . "
// output is in "excel/jtest.xls"
//
//////////////////////////////////////////////////////////////////////////////////

import java.sql.*;
import java.io.IOException;
import java.io.FileOutputStream;

import org.apache.poi.hssf.usermodel.HSSFCell;
import org.apache.poi.hssf.usermodel.HSSFRow;
import org.apache.poi.hssf.usermodel.HSSFSheet;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;

public class JSQL2XLS {

    public static void main (String[] parameters)
    {

        int rowNum = 0;
        short colNum = 0;

        String SQLstatement = parameters[0];

        Connection connection = null;

        try {

            // Load Java JDBC driver.
            Class.forName("com.ibm.db2.jdbc.app.DB2Driver");          // native
            //Class.forName("com.ibm.as400.access.AS400JDBCDriver");  // toolbox

            // Get a connection to the database.
            connection = DriverManager.getConnection
                 ("jdbc:db2://localhost" , "user", "password");       // native
                 //("jdbc:as400://localhost" , "user", "password");   // toolbox

            DatabaseMetaData dmd = connection.getMetaData ();

            // execute the query.
            Statement select = connection.createStatement ();
            ResultSet rs = select.executeQuery (SQLstatement);

            // create workbook and sheet
            HSSFWorkbook wb = new HSSFWorkbook();
            HSSFSheet sheet = wb.createSheet();

            // declare row, cell reference
            HSSFRow row = null;
            HSSFCell cell = null;

            // get information about the result set.
            ResultSetMetaData rsmd = rs.getMetaData ();
            int columnCount = rsmd.getColumnCount ();
            String[] columnLabels = new String[columnCount];

            // output the column headings.
            row = sheet.createRow(rowNum++);        // create the row
            for (colNum = (short) 0; colNum < columnCount; colNum++) {
                cell = row.createCell(colNum);     // create the cell
                String label = rsmd.getColumnLabel(colNum+1);
                cell.setCellValue(label);

            }

            // fetch records
            while (rs.next ()) {
                row = sheet.createRow(rowNum++);    // create the row
                for (colNum = (short) 0; colNum < columnCount; colNum++) {
                    cell = row.createCell(colNum);  // create the cell
                    int colType = rsmd.getColumnType (colNum+1); // get type
                    if (colType == 3) {                          // ..numeric
                       double dvalue = rs.getDouble (colNum+1);
                       if (rs.wasNull ()) {
                          String nvalue = "<null>";
                          cell.setCellValue(nvalue);
                       } else {
                          cell.setCellValue(dvalue);
                       }
                    } else {                                      // ..string
                       String avalue = rs.getString (colNum+1);
                       if (rs.wasNull ()) avalue = "<null>";
                       cell.setCellValue(avalue);
                    }

                 }

            }

            // write the Workbook
            FileOutputStream fileOut = new FileOutputStream("excel/jtest.xls");
            wb.write(fileOut);
            fileOut.close();
        }

        catch (Exception e) {
            System.out.println ();
            System.out.println ("ERROR: " + e.getMessage());
        }

        finally {

            // Clean up.
            try {
                if (connection != null)
                    connection.close ();
            }
            catch (SQLException e) {
                // Ignore.
            }
        }

        System.exit (0);
    }

}
